@@ -3,7 +3,7 @@ use serde::{Serialize, Deserialize};
 use super::FailResponse;
 
 impl crate::FireAuth {
-    pub async fn sign_in_email(&self, email: String, password: String, return_secure_token: bool) -> Result<Response, Error> {
+    pub async fn sign_in_email(&self, email: &str, password: &str, return_secure_token: bool) -> Result<Response, Error> {
         let url = format!(
             "https://identitytoolkit.googleapis.com/v1/accounts:signInWithPassword?key={}",
             self.api_key,
@@ -32,13 +32,13 @@ impl crate::FireAuth {
 
 #[derive(Debug, Serialize)]
 #[serde(rename_all = "camelCase")]
-struct SignInPayload {
-    email: String,
-    password: String,
+struct SignInPayload<'a> {
+    email: &'a str,
+    password: &'a str,
     return_secure_token: bool,
 }
 
-#[derive(Debug, Deserialize)]
+#[derive(Debug, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Response {
     pub kind: String,
