@@ -1,6 +1,9 @@
-mod api;
-pub mod error;
+pub mod api;
+mod error;
 
+pub use error::Error;
+
+#[derive(Debug)]
 pub struct FireAuth {
     pub api_key: String, // web api key
 }
